import {BaseObject, Rectangle} from '@/pdf-element-marker'
import LabeledRect from '@/fabric/labeled.rect'
import {reactive, Ref, toRaw} from 'vue'
import useVModelEmit from '@/composables/useUpdateInternalModel'
import {v4 as uuidV4} from 'uuid'

export default (totalPages: Ref<number>) => {
    const {setInternalModel: vModelEmit} = useVModelEmit()

    const deleteObject = (item: BaseObject, pageNum: number) => {
        const canvas = item.canvas
        canvas?.remove(toRaw(item))
        vModelEmit(pageNum, canvas)
    }
    const cloneObject = (item: BaseObject, pageNum: number) => {
        // Not doing a built-in fabric clone as it's not working
        const rect = new LabeledRect(reactive({
            left: item.left + 20,
            top: item.top + 20,
            originX: item.originX,
            originY: item.originY,
            width: item.width,
            height: item.height,
            stroke: item.stroke,
            strokeWidth: item.strokeWidth,
            strokeUniform: item.strokeUniform,
            cornerSize: item.cornerSize,
            borderColor: 'rgba(0, 0, 255, 0.5)',
            cornerColor: 'rgba(0, 0, 255, 0.5)',
            label: `${item.label} (copy)`,
            fill: item.fill,
            transparentCorners: item.transparentCorners,
            uid: uuidV4(),
        })) as Rectangle

        rect.setControlVisible('mtr', item.isRotatable || false)
        toRaw(item.canvas)?.add(rect)
        vModelEmit(pageNum, item.canvas)
        item.canvas?.setActiveObject(rect)
    }

    return {
        deleteObject,
        cloneObject,
    }
}
