import {reactive, toRefs} from '@vue/reactivity'
import {DataRectangle} from "@/pdf-element-marker";

/**
 * Define our state
 *
 * This state is mutable in the function below, but if we pass it to the component without `toRefs` it will not mutate.
 */
const state = reactive({
    markerModel: [[]] as DataRectangle[][],
})

export default () => {
    const resetModelPage = (pageNumber: number) => state.markerModel[pageNumber - 1] = []

    const addToModel = (pageNumber: number, ...items: DataRectangle[]) => {
        if (state.markerModel.length < pageNumber) {
            state.markerModel.push([])
        }

        items = items.reverse().filter((drawRectangle, index, self) =>
            index === self.findIndex(rect => rect.uid === drawRectangle.uid)
        ).reverse()

        state.markerModel[pageNumber - 1].push(...items)
    }

    /**
     * Return the state as a `reference` to make it mutable.
     */
    return {
        state: toRefs(state),
        addToModel,
        resetModelPage,
    }
}
